@@ -31,7 +31,8 @@ def open_dataset():
     global elevation
 
     dir = app.config.get('ELEVATION_DIRECTORY', Dataset.default_location)
-    elevation = Dataset(dir)
+    res = app.config.get('ELEVATION_TILE_RESOLUTION', Dataset.default_res)
+    elevation = Dataset(dir, expected_res=res)
 
 
 @app.route('/<latitude>,<longitude>')
@@ -44,17 +45,3 @@ def get_elevation(latitude, longitude):
         abort(400)
 
     return jsonify({"elevation": result})
-
-
-def main():
-    if sys.argv[1:] == ["--debug"]:
-        app.run(debug=True)
-    elif sys.argv[1:] == []:
-        app.run()
-    else:
-        print("Usage: {} [--debug]".format(sys.argv[0]), file=sys.stderr)
-        sys.exit(2)
-
-
-if __name__ == "__main__":
-    main()
